@@ -11,7 +11,7 @@ def call_anthropic_api(model: str, messages: list[dict], temperature: float, max
     """Call Anthropic API directly."""
     api_key = os.getenv("ANTHROPIC_API_KEY")
     if not api_key:
-        raise AIError.model_error("ANTHROPIC_API_KEY not found in environment variables")
+        raise AIError.authentication_error("ANTHROPIC_API_KEY not found in environment variables")
 
     url = "https://api.anthropic.com/v1/messages"
     headers = {"x-api-key": api_key, "anthropic-version": "2023-06-01", "content-type": "application/json"}
@@ -42,6 +42,10 @@ def call_anthropic_api(model: str, messages: list[dict], temperature: float, max
             raise AIError.model_error("Anthropic API returned empty content")
         return content
     except httpx.HTTPStatusError as e:
+        if e.response.status_code == 429:
+            raise AIError.rate_limit_error(f"Anthropic API rate limit exceeded: {e.response.text}") from e
         raise AIError.model_error(f"Anthropic API error: {e.response.status_code} - {e.response.text}") from e
+    except httpx.TimeoutException as e:
+        raise AIError.timeout_error(f"Anthropic API request timed out: {str(e)}") from e
     except Exception as e:
         raise AIError.model_error(f"Error calling Anthropic API: {str(e)}") from e
